Text

Struct Text 

pub struct Text(/* private fields */);

Implementations

Source

impl Text

pub fn with_style(style: Style) -> Text

pub fn new() -> Text

pub fn push_str(&mut self, s: impl AsRef<str>) -> Result<(), NewlineError>

pub fn push_string(&mut self, s: String) -> Result<(), NewlineError>

pub fn current_span_mut(&mut self) -> &mut Span<'static>

pub fn set_style(&mut self, style: Style)

pub fn new_span(&mut self, style: Style)

pub fn extend(&mut self, other: &mut Text)

Extend self with more text. Styles are patched along the way.

pub fn spans(&self) -> &Vec<Span<'static>>

pub fn complete(self, line: Line) -> Line

pub fn swap_complete(&mut self, line: Line) -> Line

Replace self with a new Text which picks up where the provided line appended to the current text leaves off stylistically.

pub fn empty(&self) -> bool

pub fn style(&self) -> Style